USBQualityTest — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.03_7f9fc90 documentation »
- Python programs and modules »

# USBQualityTest

Test quality of USB connection to weather station

    usage: python USBQualityTest.py [options]
    options are:
     -h | --help           display this help
     -v | --verbose        increase amount of reassuring messages
                           (repeat for even more messages e.g. -vvv)

The USB link to my weather station is not 100% reliable. The data read from the station by the computer is occasionally corrupted, perhaps by interference. I’ve been trying to solve this by putting ferrite beads around the USB cable and relocating possible interference sources such as external hard drives. All without any success so far.

This program tests the USB connection for errors by continuously reading the entire weather station memory (except for those parts that may be changing) looking for errors. Each 32-byte block is read twice, and if the two readings differ a warning message is displayed. Also displayed are the number of blocks read, and the number of errors found.

I typically get one or two errors per hour, so the test needs to be run for several hours to produce a useful measurement. Note that other software that accesses the weather station (such as Hourly or LiveLog) must not be run while the test is in progress.

If you run this test and get no errors at all, please let me know. There is something good about your setup and I’d love to know what it is!

Functions

`main`([argv]) |

`USBQualityTest.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.03_7f9fc90 documentation »
- Python programs and modules »